@@ -1,12 +1,12 @@
 ﻿# -*- coding: utf-8 -*-
 import os
 import re
-import json
+import traceback
 import struct
 import threading
 import six
 import socket
-from functools import wraps
+from functools import wraps, partial
 from airtest.core.android.constant import STFLIB
 from airtest.utils.logger import get_logger
 from airtest.utils.nbsp import NonBlockingStreamReader
@@ -38,10 +38,10 @@ class Minicap(BaseCap):
     """
 
     VERSION = 5
-    RECVTIMEOUT = None
+    RECVTIMEOUT = 3  # default value is None, but the version above 1.2.7 is changed to 3s
     CMD = "LD_LIBRARY_PATH=/data/local/tmp /data/local/tmp/minicap"
 
-    def __init__(self, adb, projection=None, rotation_watcher=None, display_id=None):
+    def __init__(self, adb, projection=None, rotation_watcher=None, display_id=None, ori_function=None):
         """
         :param adb: adb instance of android device
         :param projection: projection, default is None. If `None`, physical display size is used
@@ -49,7 +49,7 @@ class Minicap(BaseCap):
         super(Minicap, self).__init__(adb=adb)
         self.projection = projection
         self.display_id = display_id
-        self.ori_function = self.get_display_info
+        self.ori_function = ori_function or self.adb.get_display_info
         self.frame_gen = None
         self.stream_lock = threading.Lock()
         self.quirk_flag = 0
@@ -59,6 +59,9 @@ class Minicap(BaseCap):
             # Minicap needs to be reconnected when switching between landscape and portrait
             # minicap需要在横竖屏转换时，重新连接
             rotation_watcher.reg_callback(lambda x: self.update_rotation(x * 90))
+        self.cleanup_func = []
+        # Force cleanup on exit
+        reg_cleanup(self.teardown_stream)
 
     @ready_method
     def install_or_upgrade(self):
@@ -145,29 +148,6 @@ class Minicap(BaseCap):
         self.adb.shell("chmod 755 %s/minicap.so" % device_dir)
         LOGGING.info("minicap installation finished")
 
-    @on_method_ready('install_or_upgrade')
-    def get_display_info(self):
-        """
-        Get display info by minicap
-
-        Warnings:
-            It might segfault, the preferred way is to get the information from adb commands
-
-        Returns:
-            display information
-
-        """
-        if self.display_id:
-            display_info = self.adb.shell("{0} -d {1} -i".format(self.CMD, self.display_id))
-        else:
-            display_info = self.adb.shell("%s -i" % self.CMD)
-        match = re.compile(r'({.*})', re.DOTALL).search(display_info)
-        display_info = match.group(0) if match else display_info
-        display_info = json.loads(display_info)
-        display_info["orientation"] = display_info["rotation"] / 90
-        display_info = self.adb.update_cur_display(display_info)
-        return display_info
-
     @on_method_ready('install_or_upgrade')
     def get_frame(self, projection=None):
         """
@@ -271,6 +251,10 @@ class Minicap(BaseCap):
             stopping = True
         else:
             stopping = False
+        self.cleanup_func.append(s.close)
+        self.cleanup_func.append(nbsp.kill)
+        self.cleanup_func.append(partial(kill_proc, proc))
+        self.cleanup_func.append(partial(self.adb.remove_forward, "tcp:%s" % localport))
         yield stopping
 
         while not stopping:
@@ -278,6 +262,9 @@ class Minicap(BaseCap):
                 s.send(b"1")
             # recv frame header, count frame_size
             if self.RECVTIMEOUT is not None:
+                # Some mobile phones may keep waiting for data when switching between horizontal and vertical screens,
+                # and the connection is not closed, resulting in a black screen
+                # Set the timeout to 3s(airtest>=1.2.7)
                 header = s.recv_with_timeout(4, self.RECVTIMEOUT)
             else:
                 header = s.recv(4)
@@ -287,14 +274,16 @@ class Minicap(BaseCap):
                 stopping = yield None
             else:
                 frame_size = struct.unpack("<I", header)[0]
-                frame_data = s.recv(frame_size)
+                if self.RECVTIMEOUT is not None:
+                    frame_data = s.recv_with_timeout(frame_size, self.RECVTIMEOUT)
+                else:
+                    frame_data = s.recv(frame_size)
                 stopping = yield frame_data
 
         LOGGING.debug("minicap stream ends")
-        s.close()
-        nbsp.kill()
-        kill_proc(proc)
-        self.adb.remove_forward("tcp:%s" % localport)
+        # teardown stream() cannot be called directly because the connection may be rebuilt multiple times
+        # while the screen is rotated, and self.frame_gen gets stuck
+        self._cleanup()
 
     def _setup_stream_server(self, lazy=False):
         """
@@ -336,7 +325,6 @@ class Minicap(BaseCap):
             kill_proc(proc)
             raise RuntimeError("minicap server quit immediately")
 
-        reg_cleanup(kill_proc, proc)
         self._stream_rotation = int(display_info["rotation"])
         return proc, nbsp, localport
 
@@ -394,6 +382,20 @@ class Minicap(BaseCap):
         LOGGING.debug("update_rotation: %s" % rotation)
         self._update_rotation_event.set()
 
+    def _cleanup(self):
+        """
+        Cleanup minicap process and stream reader
+
+        主动将minicap建立的各个连接关闭
+        与snippet.py中的CLEANUP_CALLS功能相同，但是允许主动调用，避免异常退出时有遗漏进程没清理干净
+
+        Returns:
+
+        """
+        for func in self.cleanup_func:
+            func()
+        self.cleanup_func = []
+
     def teardown_stream(self):
         """
         End the stream
@@ -402,6 +404,8 @@ class Minicap(BaseCap):
             None
 
         """
+        # clean up established connections
+        self._cleanup()
         if not self.frame_gen:
             return
         try:
@@ -412,5 +416,3 @@ class Minicap(BaseCap):
         else:
             LOGGING.warn("%s tear down failed" % self.frame_gen)
         self.frame_gen = None
-
-
