@@ -12,9 +12,9 @@ class Settings(object):
     LOG_FILE = "log.txt"
     RESIZE_METHOD = staticmethod(cocos_min_strategy)
     # keypoint matching: kaze/brisk/akaze/orb, contrib: sift/surf/brief
-    CVSTRATEGY = ["mstpl", "tpl", "surf", "brisk"]
-    if LooseVersion(cv2.__version__) > LooseVersion('3.4.2'):
-        CVSTRATEGY = ["mstpl", "tpl", "sift", "brisk"]
+    CVSTRATEGY = ["mstpl", "tpl", "sift", "brisk"]
+    if LooseVersion('3.4.2') < LooseVersion(cv2.__version__) < LooseVersion('4.4.0'):
+        CVSTRATEGY = ["mstpl", "tpl", "brisk"]
     KEYPOINT_MATCHING_PREDICTION = True
     THRESHOLD = 0.7  # [0, 1]
     THRESHOLD_STRICT = None  # dedicated parameter for assert_exists
